@@ -4,21 +4,22 @@
 //! the `ethcontract-derive` crate.
 
 pub mod abiext;
+pub mod artifact;
 pub mod bytecode;
+pub mod contract;
 pub mod errors;
 pub mod hash;
-pub mod truffle;
 
 pub use crate::abiext::FunctionExt;
 pub use crate::bytecode::Bytecode;
-pub use crate::truffle::Artifact;
+pub use crate::contract::Contract;
 pub use ethabi::{self as abi, Contract as Abi};
-use serde::Deserialize;
+use serde::{Deserialize, Serialize};
 pub use web3::types::Address;
 pub use web3::types::H256 as TransactionHash;
 
 /// Information about when a contract instance was deployed
-#[derive(Debug, Clone, Copy, PartialEq, Deserialize)]
+#[derive(Debug, Clone, Copy, PartialEq, Serialize, Deserialize)]
 #[serde(untagged)]
 pub enum DeploymentInformation {
     /// The block at which the contract was deployed
